==> mangokit-1.1.31.tar.gz: mangokit-1.1.31/mangokit/tools/database/mysql_connect.py <==
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description:
# @Time   : 2023-09-09 23:17
# @Author : 毛鹏
import pymysql
from pymysql.err import InternalError, OperationalError, ProgrammingError

from mangokit.exceptions import *
from mangokit.models.models import MysqlConingModel


class MysqlConnect:

    def __init__(self, mysql_config: MysqlConingModel, is_c: bool = True, is_rud: bool = True):
        self.is_c = is_c
        self.is_rud = is_rud
        try:
            self.connection = pymysql.connect(
                host=mysql_config.host,
                port=mysql_config.port,
                user=mysql_config.user,
                password=mysql_config.password,
                database=mysql_config.database,
                autocommit=True
            )
        except OperationalError:
            raise ToolsError(*ERROR_MSG_0001)
        except InternalError:
            raise ToolsError(*ERROR_MSG_0033, value=(mysql_config.database,))

    def __del__(self):
        if hasattr(self, 'connection') and self.connection:
            self.close()

    def close(self):
        if self.connection:
            self.connection.close()
            self.connection = None

    def condition_execute(self, sql: str) -> list[dict] | list | int | None:
        sql = sql.strip().upper()
        result = None
        if sql.startswith('SELECT'):
            if self.is_c:
                result = self.execute(sql)
        elif sql.startswith('INSERT') or sql.startswith('UPDATE') or sql.startswith('DELETE'):
            if self.is_rud:
                result = self.execute(sql)
        else:
            raise ToolsError(*ERROR_MSG_0034, value=(sql,))
        return result

    def execute(self, sql) -> list[dict] | int | list:
        with self.connection.cursor() as cursor:
            try:
                cursor.execute(sql)
            except ProgrammingError:
                raise ToolsError(*ERROR_MSG_0034, value=(sql,))
            except InternalError:
                raise ToolsError(*ERROR_MSG_0035)
            except OperationalError:
                raise ToolsError(*ERROR_MSG_0034, value=(sql,))
            if sql.strip().upper().startswith('SELECT'):
                columns = [col[0] for col in cursor.description]
                return [dict(zip(columns, row)) for row in cursor.fetchall()]
            else:
                result = cursor.rowcount
                self.connection.commit()
                return result

==> mangokit-1.3.2.tar.gz: mangokit-1.3.2/mangokit/tools/database/mysql_connect.py <==
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description:
# @Time   : 2023-09-09 23:17
# @Author : 毛鹏
import pymysql
from pymysql.err import InternalError, OperationalError, ProgrammingError

from mangokit.exceptions import *
from mangokit.models.models import MysqlConingModel


class MysqlConnect:

    def __init__(self, mysql_config: MysqlConingModel, is_c: bool = True, is_rud: bool = True):
        self.is_c = is_c
        self.is_rud = is_rud
        try:
            self.connection = pymysql.connect(
                host=mysql_config.host,
                port=mysql_config.port,
                user=mysql_config.user,
                password=mysql_config.password,
                database=mysql_config.database,
                autocommit=True
            )
        except OperationalError:
            raise MangoKitError(*ERROR_MSG_0001)
        except InternalError:
            raise MangoKitError(*ERROR_MSG_0033, value=(mysql_config.database,))

    def __del__(self):
        if hasattr(self, 'connection') and self.connection:
            self.close()

    def close(self):
        if self.connection:
            self.connection.close()
            self.connection = None

    def condition_execute(self, sql: str) -> list[dict] | list | int | None:
        sql1 = sql.strip().upper()
        result = None
        if sql1.startswith('SELECT'):
            if self.is_c:
                result = self.execute(sql)
        elif sql1.startswith('INSERT') or sql1.startswith('UPDATE') or sql1.startswith('DELETE'):
            if self.is_rud:
                result = self.execute(sql)
        else:
            raise MangoKitError(*ERROR_MSG_0034, value=(sql,))
        return result

    def execute(self, sql) -> list[dict] | int | list:
        with self.connection.cursor() as cursor:
            try:
                cursor.execute(sql)
            except ProgrammingError:
                raise MangoKitError(*ERROR_MSG_0034, value=(sql,))
            except InternalError:
                raise MangoKitError(*ERROR_MSG_0035)
            except OperationalError:
                raise MangoKitError(*ERROR_MSG_0034, value=(sql,))
            if sql.strip().upper().startswith('SELECT'):
                columns = [col[0] for col in cursor.description]
                return [dict(zip(columns, row)) for row in cursor.fetchall()]
            else:
                result = cursor.rowcount
                self.connection.commit()
                return result
